/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_3Q_HPP_
#define _HEAVY_CONTEXT_WSTD_3Q_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalBiquad.h"
#include "HvMath.h"
#include "HvSignalVar.h"
#include "HvControlSystem.h"
#include "HvSignalLine.h"
#include "HvControlVar.h"
#include "HvControlBinop.h"
#include "HvControlUnop.h"
#include "HvControlCast.h"
#include "HvControlSlice.h"
#include "HvControlIf.h"

class Heavy_WSTD_3Q : public HeavyContext {

 public:
  Heavy_WSTD_3Q(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_3Q();

  const char *getName() override { return "WSTD_3Q"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 6; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_HWc6IAVH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ce5rxbxq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6gUx0XYH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Tnmu1lv4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XpwdKxvD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_7GpSjT8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_H6SHbP19_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_GVAHID5V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NPvjFeOh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lREsODL2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_NOEjEeqx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sdUxd6eY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hebEyLoZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oU2ICHov_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lS41I3r8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nZsjguEO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YKHKxlSe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7H7cRPxv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0D7cfGEB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LBGzAWnV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ws4wWnVY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e1v6i4DW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Or5OpTyP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QOG5Uzqy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5zilqTyv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8dUk5Jsp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CZOBptAh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jkYquXqR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mjeKcVz5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CywyZjSe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cjR2xmis_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Fubiy2pq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QTsvA0Mx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_KZ7rifeI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bRwDwCMP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PMaK0T6m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UvN54Zex_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WbapgckI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V9uWouzC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ppK8sCh3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MTf1u3qI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5hHjgP42_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zeDMGH5o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_w9NBxhbz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nlY7zE1j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_grDK0kDP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2Fn7OGn9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4JXLlsLe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oZEDaV58_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Lx9ePBEg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_akXpXCpU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fkaFYrp5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZOIUfFZu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FTyQwbOS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5kjLC2zW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_f64dc6Ze_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ltGoyQ6p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NHVfXl6S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mB9TgyXa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sFnCyhdl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bQCj9vgC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_86Zv9OBp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_obdC2t6F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GBRRRtck_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sBxihtUW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tkvwgqbu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_RYswPgDf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2hn0BXwI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mahOD37x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jZggJWzt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5ttfvSsM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7GxWs1bK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jnNnTR5G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WZT39LHz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2RLVZuxC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t253hYLE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7JvlI3Ew_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ykOqk3vG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qeoZqnE7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_hsbSUrwK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6xp7lZBY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_PCOxjgaW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_72hjn8vI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_uj10FR44_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_R7e50zt1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_mPVmYHM2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_yRzJStOw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_p8aROdCI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XOAuYbrf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_39TDzEcA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lqomuwQJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_h9lE4Eco_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Vs6tcyoq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_79C5OsxI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wmE0tAyq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gjvVG19i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_75jGIM68_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wUOdkBnY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wslGGkuc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RQ1GGBah_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_i4pxS23S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_rICeGu8M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AAFNl6fl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IEajVnpk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MVF22Fet_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eqqIpH1g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e9CVycuu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_CLznDu1Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_JhKUdxNa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yrOpTZbh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Hhr3nVh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CsHgHzWQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0olvmh1p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9t4JqvkL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_n3uU8nf0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MikBJ7oD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mqw05fub_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6Ms1XaY3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HpoNkfCJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qZqDFUl4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xtq81xE8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VLxRrWeJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rOspRtJ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MiRnC7Nx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KoNLIQx5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sdv4W6oW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_B4ZV4PFF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zrHJeHWF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ez2WBGMW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_tlngK0PH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_kp65Z9aJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hFhKxWAH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V8rydRkv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pTQ0Qnuj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_psXE1nIZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ShLPTjGw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_baGmcKXy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lNkn3Ga1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DVtTEkIF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dH6Q1HMc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qCysgz3g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9zMSysjr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_goL8RmPT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4ppdJWjp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_33IeH11L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0z7HSICw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lPmo5MIO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ehuXJJMu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OoFiVsII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X6K5cwD2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GYuUx6K0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o8cF8ZmU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pynSfx5P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_J39f5cG4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ELAmGd86_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NjtGDiyb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Hk59qfGE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Tz30KZxw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_1plNytzE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r5sNHAT3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p34ApFs5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Iscot13q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bazRa21Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kvjF0Lio_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_DkxbKqiY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_0qx9fsCN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i8kJKOuO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ieKzztyK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZUUO2dKD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O0awxrfB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xymPz2G6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F7uy1CWm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TfvkaB7R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9NAuyPgM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JjGrW07W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mSlBhfh9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RjecEVWI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Abd7Syg8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v7aGQMQk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RNvjQOu8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_wNBVHRqO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_QzNZwLbh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_YVPmeuJq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zLitiQ2g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3797Uk5e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9pRs5fRM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jy68QWLQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nR8rJypK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JVHWS8zK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5ucv3A4F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WDLmnjnF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FiX5h6RI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MUGQLzwg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1XTCvq0i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Lc9avZVt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jRHropoD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HFTw4eVw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CHh77P1J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uUJbkzYn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AY670gQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0UwOKERn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e57ktr5M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gErphokp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WYWw58Cl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LTzycHrS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VZ9pP0oi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_whsT4UHh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hWL8L5jI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xPUTXFnn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OrXuwMh8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X7kS4H3c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6pEGmShW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L2PUsRn2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t7dJTIgE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_2LORDAR5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_voM4PwaC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ndr2U3Or_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g0pRj59r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6e7Uhztx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MC3ruZ0a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tqmrxTbP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U4iwoFqN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U2izkEKN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0w2py1fN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r8yZjyft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PeeSOgnA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ky9rbsWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5N2Yut5A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kOvoJ7IO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4sryQkdM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hiedeIiu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OacFCc86_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gkZ1VSnN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SazCgKBi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0Z4b2KRU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o8YJpPLT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P5HW5lkY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ZnSoxx0U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CeNVQz7V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_z8tDeLpp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_35FPnb94_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IeZxm0sk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8sCg6Wc2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XF2Yxubb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BVvrbyqE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZocdQ1oE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DThiTjcB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ppz3eGOF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HQxjBAwj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3dxeSbG9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OGEkHd6R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mi3XEp6F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Gj6mDK0W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JhoW8jiP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MgLaxgtk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vfEnhVAT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vnHim1xH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PYp49lsZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wTvzGW49_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1H9NTrv7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oR6oqa7j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ua0qyKZI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RbKn87Hk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_40uASuSw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YnI89Coo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_EYFOKcCv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_wzqUEWLI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bSVi69lK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_7vfvMTHD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zKO0yXAj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jEHIso5k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Fm0O7eHD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A5WhICxn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LzGT4VPn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4BbxV0aM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ho7VqfSe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3EsQ6Gtx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VOq3iSEy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0siDkK0c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KL0hPJly_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6XC6vGpq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Xd17t7Hy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e082C7Xp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Amu8Hie0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EHTlRCjq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zINyl99i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DuqAinHb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZCoFoA37_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a21TpIvj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QoVU9FPP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k2ZgYhmO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XDP4YHYl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IeRnhihU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_q1RKN5lq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_mkTTYJGS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ifh0qtTi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DMCqLlJl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Un9CVF5Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iZVX67Zz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZiCIqc5O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ui93XzCr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J8HsdcKl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NwVqlYzo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JHGe1hPB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_PhExn7rk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_57T8CW4h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cxc0SEYT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ulwavWoB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c5ty18EX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rbj3NDDA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_etErzS8q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dDz2wwqN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_L7g204Nk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7yKmi1Oo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MBlKgfbn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_G1GFjXpu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_oandNBvJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SbVD9Wkg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V22FczGd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vOJspheo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_guNuAHOB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lfYsGEfG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fEI8sh8u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_asrgPICB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_os0gKze8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HxQD8eYB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e4h3VEOG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jztiJFT5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BbA6QSwf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N1svQhTU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZW0v84Xw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x9lxETPZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VNNV4Yfr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JCY7R0Y2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gyNJMxj5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dXn6eJbE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T61QZb1U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6CSP1KQm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Z1tctfYq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WVYmsszj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_qjUAjRml_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hVuOfNkt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_QrW0hsfI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_psJcEKXa_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_k6BjqjOF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AAquVi1M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_zh0om49V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_orlEtH7m_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Qgmx7djy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_b7cMftGC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Cg4RHL7g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xLnwjVvT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_xAjTEgbf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mNkJr63Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_dFRCr0cK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UC7jAYSD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KeWNhldV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fRqjxeP2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m6Ao7qSS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9gizje5a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b1P1REeA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_n8y4p1Xh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_VdH641wS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PYhkF7J8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s8NK7XYQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6wkdxJmi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UlDfxO0L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P4C8fW58_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_XOoQcJdE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_g42hRPmL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2E0MXywV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DDDeUtpA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f5KTaHtA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UIB00eJg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Aa7hbjIS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PA4hkrhS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iJwnpbk0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cKfur8Rr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8kcwDvEV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V7MTcYuj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hh8Ur0Un_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aREbkuFG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LQVMuCHc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KGqyefLj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FdrdMIL8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oOZcm13O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yZewYV3o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gh6YDOAe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lQcIFkBw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_6W146eRr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_yyUqCSc1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_TGCw4Spv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lWubYwpO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FXdmFM0s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2CNndEvB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IGjaglAd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_THLGhb1y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UtWHJjmu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SRPR7m2H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UtLZFthB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vxc3xI2t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_epCKmSLo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PC7INQrH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s1VFcFPf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AplqDEY1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8m73RV55_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HitjKJcZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6antjCjo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OjUl7MIY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qOacrByQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X48kFMVp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CVOky5bp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_D9gd0JfN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P3GASDFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l5cZG1Yg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Mz37AkSD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_J4nXO2Ni_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nuTbPttV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_yPW16tj7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_KF1J2z76_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a8ypJpcH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QJ8vVdai_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4fNfDQLa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZSrSyQuT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VSuGDP1p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3wmIAXBi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_bKz91KEi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gMjWVFIg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zYX15Pjx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_acBZl4Pv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ftxYqkKq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_16nfApts_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Avd4E3nM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AfTpKEnB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Z94GvJiG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vDL4WMUD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ILpZBe6Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SQTfJ9Ea_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_m0aSb2dn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YYQ9loYG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RbPnW3Km_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_lArX4fcI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_q0JWF427_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Mjsd84wx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uggBWCpt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sachAfId_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YgwroRf3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3Uu7IY0a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_myMUcEvP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6pogM5Av_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RP7QTFDe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ybEOgmi3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MFcgAHxD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6nXViwUt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OMgNXSWu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_opYS0mMY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jPbEAbXq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bMqpKjca_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1bRP4tyC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zhy6H6Ov_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zwMdrh8l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vJyJPrj8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lEiBu7Vk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_73rvPnQI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_geH0Q91o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MpXGpX6K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vGvp74Bz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BsaGWeq9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_bXUOV6QY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_MxdtgRRw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BJFYweXr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KODOsvvH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DWyBPkO4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N2VQLEhR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_saDxiSeX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_VYiAOTqZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_QEByBm40_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WOV9wfLH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tylbFYv7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_esqiNizP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I2aqX8c7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i4oxQJwW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IYLSnDYt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cX958Wbt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Hnx4yXhg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9pTh89uj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CK7RET7P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_81Iu2Sap_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P2JzNTBq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C2dK1pKr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XMxmGJuT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XOkQGZbm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pGHVWAFp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oj9nBeEs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JWMziohR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aavqggoP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VRQARalf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3gl339YG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_J1pFqNCy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_tXomlpUu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VHbO4qVg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dGBIHsdl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mqonuTkv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zUoJHbvO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SqWXhKt3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7U0PcHSI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9xUsWIcX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N9XjzjjN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xK8KRGzy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rQDBh4gl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_euLLcFNq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sf3fAPZA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YVBZK79v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hoMjxJR5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nZeXMroB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oXvIyUh0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z2UqJ9lu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sYefjUYZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zQE9ol4v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Bv9wxDPq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZsS7w0wI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3hkb3HLc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vJkA8iS0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q85JO5Ul_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iolx80je_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b4qNLpvW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_w79RflOK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1vkVoZxx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_dylpQ7zW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_CkgvEdwP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tonmPamw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IIn18TTA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5Pv3iQRL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eAbfmoZ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xU7QA4JM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oIAvlYH7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_5NuWKBGd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QUt9KkEO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rojG8Uj5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_60nZqGzJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bTLxkLEo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_u3oDTOhN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mRQIanqW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ytXU2vx5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YiQnWADd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AcQzEpcW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YfO8bbU9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2faIB6y2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qLIQmfxW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pO8V1uiL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KC1WVNl8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bNU4TIIN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HUPXDW5N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JIyjjiLf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8vEJqnWh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_R9cy2Ysv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XoW3Mj2f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jGqv3Vx6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dWWWTZWQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NpF0aAwr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rJ26sfS8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_73j2HJmv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JDpWucTq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ABXz7iUY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YvOqjTZ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jKu0yItj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_H175TvG0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8FmCD9sG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3ZwtFe7C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zmdp69Yx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hr6uxl1s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NSbC8Ptm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_549cncYn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OXREbOjk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Rgu1mTlv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GJ4lyiUB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nRra6L6L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wVqPRdUB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LH8SfY4G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NW8peV0P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rU5mdeiq_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_Og3Y6V0r;
  SignalLine sLine_9is7O4M7;
  SignalLine sLine_PHoJCcf1;
  SignalLine sLine_v1JlpMMw;
  SignalLine sLine_31rkQYn2;
  SignalBiquad sBiquad_s_jmzbzK8D;
  SignalLine sLine_1iPwB2LR;
  SignalLine sLine_XXoCS8vZ;
  SignalLine sLine_2KltjeBi;
  SignalLine sLine_lvl62LjQ;
  SignalBiquad sBiquad_s_TBqWJA8n;
  SignalLine sLine_HNVTpeGf;
  SignalLine sLine_trrNKxbS;
  SignalLine sLine_4NRO82kA;
  SignalLine sLine_jwNALUf6;
  SignalLine sLine_n7GjnJiv;
  SignalBiquad sBiquad_s_HYwkXwZy;
  SignalLine sLine_GGMMDpU0;
  SignalLine sLine_3vuatanm;
  SignalLine sLine_9YuILwxD;
  SignalLine sLine_666XG9v1;
  SignalLine sLine_BtP8oFJP;
  SignalBiquad sBiquad_s_uelArOWn;
  SignalLine sLine_h4Ppof0C;
  SignalLine sLine_98sQzXsc;
  SignalLine sLine_oekDbTAm;
  SignalLine sLine_oDeY93W9;
  SignalBiquad sBiquad_s_r7XiqGdg;
  SignalLine sLine_iTxriYEv;
  SignalLine sLine_fcBRm7bf;
  SignalLine sLine_UUCSAb9B;
  SignalLine sLine_CvLUvaMN;
  SignalLine sLine_XsXT1zyS;
  SignalBiquad sBiquad_s_M176WEDg;
  ControlVar cVar_HWc6IAVH;
  ControlVar cVar_ce5rxbxq;
  ControlVar cVar_6gUx0XYH;
  ControlVar cVar_Tnmu1lv4;
  ControlSlice cSlice_7GpSjT8Q;
  ControlVar cVar_H6SHbP19;
  ControlVar cVar_NPvjFeOh;
  ControlIf cIf_lREsODL2;
  ControlIf cIf_NOEjEeqx;
  ControlBinop cBinop_hebEyLoZ;
  ControlBinop cBinop_oU2ICHov;
  ControlBinop cBinop_YKHKxlSe;
  ControlBinop cBinop_7H7cRPxv;
  ControlBinop cBinop_LBGzAWnV;
  ControlIf cIf_ws4wWnVY;
  ControlBinop cBinop_e1v6i4DW;
  ControlBinop cBinop_Or5OpTyP;
  ControlBinop cBinop_5zilqTyv;
  ControlBinop cBinop_8dUk5Jsp;
  ControlBinop cBinop_CZOBptAh;
  ControlVar cVar_Fubiy2pq;
  ControlIf cIf_QTsvA0Mx;
  ControlIf cIf_KZ7rifeI;
  ControlBinop cBinop_PMaK0T6m;
  ControlBinop cBinop_UvN54Zex;
  ControlBinop cBinop_ppK8sCh3;
  ControlBinop cBinop_MTf1u3qI;
  ControlBinop cBinop_zeDMGH5o;
  ControlIf cIf_w9NBxhbz;
  ControlBinop cBinop_nlY7zE1j;
  ControlBinop cBinop_grDK0kDP;
  ControlBinop cBinop_4JXLlsLe;
  ControlBinop cBinop_oZEDaV58;
  ControlBinop cBinop_Lx9ePBEg;
  ControlVar cVar_5kjLC2zW;
  ControlIf cIf_f64dc6Ze;
  ControlIf cIf_ltGoyQ6p;
  ControlBinop cBinop_mB9TgyXa;
  ControlBinop cBinop_sFnCyhdl;
  ControlBinop cBinop_obdC2t6F;
  ControlBinop cBinop_GBRRRtck;
  ControlBinop cBinop_tkvwgqbu;
  ControlIf cIf_RYswPgDf;
  ControlBinop cBinop_2hn0BXwI;
  ControlBinop cBinop_mahOD37x;
  ControlBinop cBinop_5ttfvSsM;
  ControlBinop cBinop_7GxWs1bK;
  ControlBinop cBinop_jnNnTR5G;
  ControlIf cIf_ykOqk3vG;
  ControlSlice cSlice_hsbSUrwK;
  ControlVar cVar_6xp7lZBY;
  ControlSlice cSlice_uj10FR44;
  ControlVar cVar_R7e50zt1;
  ControlSlice cSlice_p8aROdCI;
  ControlVar cVar_XOAuYbrf;
  ControlSlice cSlice_h9lE4Eco;
  ControlVar cVar_Vs6tcyoq;
  ControlBinop cBinop_IEajVnpk;
  ControlBinop cBinop_eqqIpH1g;
  ControlBinop cBinop_e9CVycuu;
  ControlBinop cBinop_yrOpTZbh;
  ControlBinop cBinop_2Hhr3nVh;
  ControlBinop cBinop_CsHgHzWQ;
  ControlBinop cBinop_0olvmh1p;
  ControlBinop cBinop_9t4JqvkL;
  ControlVar cVar_n3uU8nf0;
  ControlBinop cBinop_MikBJ7oD;
  ControlBinop cBinop_mqw05fub;
  ControlBinop cBinop_6Ms1XaY3;
  ControlBinop cBinop_HpoNkfCJ;
  ControlBinop cBinop_qZqDFUl4;
  ControlBinop cBinop_xtq81xE8;
  ControlBinop cBinop_VLxRrWeJ;
  ControlBinop cBinop_MiRnC7Nx;
  ControlVar cVar_KoNLIQx5;
  ControlVar cVar_sdv4W6oW;
  ControlBinop cBinop_V8rydRkv;
  ControlBinop cBinop_pTQ0Qnuj;
  ControlBinop cBinop_psXE1nIZ;
  ControlBinop cBinop_baGmcKXy;
  ControlBinop cBinop_lNkn3Ga1;
  ControlBinop cBinop_DVtTEkIF;
  ControlBinop cBinop_dH6Q1HMc;
  ControlBinop cBinop_qCysgz3g;
  ControlBinop cBinop_9zMSysjr;
  ControlBinop cBinop_p34ApFs5;
  ControlBinop cBinop_bazRa21Y;
  ControlBinop cBinop_kvjF0Lio;
  ControlBinop cBinop_i8kJKOuO;
  ControlBinop cBinop_ieKzztyK;
  ControlBinop cBinop_ZUUO2dKD;
  ControlBinop cBinop_O0awxrfB;
  ControlBinop cBinop_xymPz2G6;
  ControlBinop cBinop_F7uy1CWm;
  ControlBinop cBinop_TfvkaB7R;
  ControlBinop cBinop_JjGrW07W;
  ControlVar cVar_mSlBhfh9;
  ControlVar cVar_RjecEVWI;
  ControlVar cVar_Abd7Syg8;
  ControlBinop cBinop_3797Uk5e;
  ControlBinop cBinop_9pRs5fRM;
  ControlBinop cBinop_jy68QWLQ;
  ControlBinop cBinop_JVHWS8zK;
  ControlBinop cBinop_5ucv3A4F;
  ControlBinop cBinop_WDLmnjnF;
  ControlBinop cBinop_FiX5h6RI;
  ControlBinop cBinop_MUGQLzwg;
  ControlBinop cBinop_X7kS4H3c;
  ControlBinop cBinop_L2PUsRn2;
  ControlBinop cBinop_t7dJTIgE;
  ControlBinop cBinop_ndr2U3Or;
  ControlBinop cBinop_g0pRj59r;
  ControlBinop cBinop_6e7Uhztx;
  ControlBinop cBinop_MC3ruZ0a;
  ControlBinop cBinop_tqmrxTbP;
  ControlBinop cBinop_U2izkEKN;
  ControlBinop cBinop_r8yZjyft;
  ControlBinop cBinop_PeeSOgnA;
  ControlBinop cBinop_5N2Yut5A;
  ControlBinop cBinop_kOvoJ7IO;
  ControlBinop cBinop_4sryQkdM;
  ControlBinop cBinop_OacFCc86;
  ControlVar cVar_gkZ1VSnN;
  ControlVar cVar_SazCgKBi;
  ControlVar cVar_0Z4b2KRU;
  ControlBinop cBinop_IeZxm0sk;
  ControlBinop cBinop_8sCg6Wc2;
  ControlBinop cBinop_XF2Yxubb;
  ControlBinop cBinop_ZocdQ1oE;
  ControlBinop cBinop_DThiTjcB;
  ControlBinop cBinop_ppz3eGOF;
  ControlBinop cBinop_HQxjBAwj;
  ControlBinop cBinop_3dxeSbG9;
  ControlBinop cBinop_OGEkHd6R;
  ControlBinop cBinop_Ua0qyKZI;
  ControlBinop cBinop_40uASuSw;
  ControlBinop cBinop_YnI89Coo;
  SignalVarf sVarf_jdlwQafr;
  SignalVarf sVarf_HGZX12Ff;
  SignalVarf sVarf_ffyJKatY;
  ControlSlice cSlice_wzqUEWLI;
  ControlVar cVar_bSVi69lK;
  ControlVar cVar_zKO0yXAj;
  ControlIf cIf_jEHIso5k;
  ControlIf cIf_Fm0O7eHD;
  ControlBinop cBinop_LzGT4VPn;
  ControlBinop cBinop_4BbxV0aM;
  ControlBinop cBinop_VOq3iSEy;
  ControlBinop cBinop_0siDkK0c;
  ControlBinop cBinop_6XC6vGpq;
  ControlIf cIf_Xd17t7Hy;
  ControlBinop cBinop_e082C7Xp;
  ControlBinop cBinop_Amu8Hie0;
  ControlBinop cBinop_zINyl99i;
  ControlBinop cBinop_DuqAinHb;
  ControlBinop cBinop_ZCoFoA37;
  ControlVar cVar_IeRnhihU;
  ControlIf cIf_q1RKN5lq;
  ControlIf cIf_mkTTYJGS;
  ControlBinop cBinop_DMCqLlJl;
  ControlBinop cBinop_Un9CVF5Q;
  ControlBinop cBinop_Ui93XzCr;
  ControlBinop cBinop_J8HsdcKl;
  ControlBinop cBinop_JHGe1hPB;
  ControlIf cIf_PhExn7rk;
  ControlBinop cBinop_57T8CW4h;
  ControlBinop cBinop_cxc0SEYT;
  ControlBinop cBinop_c5ty18EX;
  ControlBinop cBinop_rbj3NDDA;
  ControlBinop cBinop_etErzS8q;
  ControlVar cVar_G1GFjXpu;
  ControlIf cIf_oandNBvJ;
  ControlIf cIf_SbVD9Wkg;
  ControlBinop cBinop_vOJspheo;
  ControlBinop cBinop_guNuAHOB;
  ControlBinop cBinop_asrgPICB;
  ControlBinop cBinop_os0gKze8;
  ControlBinop cBinop_e4h3VEOG;
  ControlIf cIf_jztiJFT5;
  ControlBinop cBinop_BbA6QSwf;
  ControlBinop cBinop_N1svQhTU;
  ControlBinop cBinop_x9lxETPZ;
  ControlBinop cBinop_VNNV4Yfr;
  ControlBinop cBinop_JCY7R0Y2;
  ControlIf cIf_Z1tctfYq;
  ControlSlice cSlice_qjUAjRml;
  ControlVar cVar_hVuOfNkt;
  ControlSlice cSlice_k6BjqjOF;
  ControlVar cVar_AAquVi1M;
  ControlSlice cSlice_Qgmx7djy;
  ControlVar cVar_b7cMftGC;
  ControlSlice cSlice_xAjTEgbf;
  ControlVar cVar_mNkJr63Y;
  ControlBinop cBinop_s8NK7XYQ;
  ControlBinop cBinop_UlDfxO0L;
  ControlBinop cBinop_P4C8fW58;
  ControlBinop cBinop_2E0MXywV;
  ControlBinop cBinop_DDDeUtpA;
  ControlBinop cBinop_f5KTaHtA;
  ControlBinop cBinop_UIB00eJg;
  ControlBinop cBinop_Aa7hbjIS;
  ControlVar cVar_PA4hkrhS;
  ControlBinop cBinop_iJwnpbk0;
  ControlBinop cBinop_cKfur8Rr;
  ControlBinop cBinop_8kcwDvEV;
  ControlBinop cBinop_V7MTcYuj;
  ControlBinop cBinop_Hh8Ur0Un;
  ControlBinop cBinop_aREbkuFG;
  ControlBinop cBinop_LQVMuCHc;
  ControlBinop cBinop_FdrdMIL8;
  ControlVar cVar_oOZcm13O;
  ControlVar cVar_yZewYV3o;
  ControlBinop cBinop_FXdmFM0s;
  ControlBinop cBinop_2CNndEvB;
  ControlBinop cBinop_IGjaglAd;
  ControlBinop cBinop_UtWHJjmu;
  ControlBinop cBinop_SRPR7m2H;
  ControlBinop cBinop_UtLZFthB;
  ControlBinop cBinop_vxc3xI2t;
  ControlBinop cBinop_epCKmSLo;
  ControlBinop cBinop_PC7INQrH;
  ControlBinop cBinop_QJ8vVdai;
  ControlBinop cBinop_ZSrSyQuT;
  ControlBinop cBinop_VSuGDP1p;
  ControlBinop cBinop_gMjWVFIg;
  ControlBinop cBinop_zYX15Pjx;
  ControlBinop cBinop_acBZl4Pv;
  ControlBinop cBinop_ftxYqkKq;
  ControlBinop cBinop_16nfApts;
  ControlBinop cBinop_Avd4E3nM;
  ControlBinop cBinop_AfTpKEnB;
  ControlBinop cBinop_vDL4WMUD;
  ControlVar cVar_ILpZBe6Z;
  ControlVar cVar_SQTfJ9Ea;
  ControlVar cVar_m0aSb2dn;
  ControlBinop cBinop_sachAfId;
  ControlBinop cBinop_YgwroRf3;
  ControlBinop cBinop_3Uu7IY0a;
  ControlBinop cBinop_6pogM5Av;
  ControlBinop cBinop_RP7QTFDe;
  ControlBinop cBinop_ybEOgmi3;
  ControlBinop cBinop_MFcgAHxD;
  ControlBinop cBinop_6nXViwUt;
  ControlBinop cBinop_KODOsvvH;
  ControlBinop cBinop_N2VQLEhR;
  ControlBinop cBinop_saDxiSeX;
  ControlBinop cBinop_WOV9wfLH;
  ControlBinop cBinop_tylbFYv7;
  ControlBinop cBinop_esqiNizP;
  ControlBinop cBinop_I2aqX8c7;
  ControlBinop cBinop_i4oxQJwW;
  ControlBinop cBinop_cX958Wbt;
  ControlBinop cBinop_9pTh89uj;
  ControlBinop cBinop_CK7RET7P;
  ControlBinop cBinop_P2JzNTBq;
  ControlBinop cBinop_C2dK1pKr;
  ControlBinop cBinop_XMxmGJuT;
  ControlBinop cBinop_pGHVWAFp;
  ControlVar cVar_oj9nBeEs;
  ControlVar cVar_JWMziohR;
  ControlVar cVar_aavqggoP;
  ControlBinop cBinop_mqonuTkv;
  ControlBinop cBinop_zUoJHbvO;
  ControlBinop cBinop_SqWXhKt3;
  ControlBinop cBinop_9xUsWIcX;
  ControlBinop cBinop_N9XjzjjN;
  ControlBinop cBinop_xK8KRGzy;
  ControlBinop cBinop_rQDBh4gl;
  ControlBinop cBinop_euLLcFNq;
  ControlBinop cBinop_sf3fAPZA;
  ControlBinop cBinop_vJkA8iS0;
  ControlBinop cBinop_iolx80je;
  ControlBinop cBinop_b4qNLpvW;
  SignalVarf sVarf_7AoPXQxb;
  SignalVarf sVarf_e4gxZoUq;
  SignalVarf sVarf_AsogQT9e;
  ControlVar cVar_w79RflOK;
  ControlVar cVar_1vkVoZxx;
  ControlBinop cBinop_eAbfmoZ0;
  ControlBinop cBinop_xU7QA4JM;
  ControlBinop cBinop_oIAvlYH7;
  ControlBinop cBinop_QUt9KkEO;
  ControlBinop cBinop_rojG8Uj5;
  ControlBinop cBinop_60nZqGzJ;
  ControlBinop cBinop_bTLxkLEo;
};

#endif // _HEAVY_CONTEXT_WSTD_3Q_HPP_
