/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_3Q.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_3Q *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_3Q_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_3Q();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_3Q::Heavy_WSTD_3Q(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_Og3Y6V0r);
  numBytes += sLine_init(&sLine_9is7O4M7);
  numBytes += sLine_init(&sLine_PHoJCcf1);
  numBytes += sLine_init(&sLine_v1JlpMMw);
  numBytes += sLine_init(&sLine_31rkQYn2);
  numBytes += sBiquad_init(&sBiquad_s_jmzbzK8D);
  numBytes += sLine_init(&sLine_1iPwB2LR);
  numBytes += sLine_init(&sLine_XXoCS8vZ);
  numBytes += sLine_init(&sLine_2KltjeBi);
  numBytes += sLine_init(&sLine_lvl62LjQ);
  numBytes += sBiquad_init(&sBiquad_s_TBqWJA8n);
  numBytes += sLine_init(&sLine_HNVTpeGf);
  numBytes += sLine_init(&sLine_trrNKxbS);
  numBytes += sLine_init(&sLine_4NRO82kA);
  numBytes += sLine_init(&sLine_jwNALUf6);
  numBytes += sLine_init(&sLine_n7GjnJiv);
  numBytes += sBiquad_init(&sBiquad_s_HYwkXwZy);
  numBytes += sLine_init(&sLine_GGMMDpU0);
  numBytes += sLine_init(&sLine_3vuatanm);
  numBytes += sLine_init(&sLine_9YuILwxD);
  numBytes += sLine_init(&sLine_666XG9v1);
  numBytes += sLine_init(&sLine_BtP8oFJP);
  numBytes += sBiquad_init(&sBiquad_s_uelArOWn);
  numBytes += sLine_init(&sLine_h4Ppof0C);
  numBytes += sLine_init(&sLine_98sQzXsc);
  numBytes += sLine_init(&sLine_oekDbTAm);
  numBytes += sLine_init(&sLine_oDeY93W9);
  numBytes += sBiquad_init(&sBiquad_s_r7XiqGdg);
  numBytes += sLine_init(&sLine_iTxriYEv);
  numBytes += sLine_init(&sLine_fcBRm7bf);
  numBytes += sLine_init(&sLine_UUCSAb9B);
  numBytes += sLine_init(&sLine_CvLUvaMN);
  numBytes += sLine_init(&sLine_XsXT1zyS);
  numBytes += sBiquad_init(&sBiquad_s_M176WEDg);
  numBytes += cVar_init_f(&cVar_HWc6IAVH, 0.0f);
  numBytes += cVar_init_f(&cVar_ce5rxbxq, 0.0f);
  numBytes += cVar_init_f(&cVar_6gUx0XYH, 0.0f);
  numBytes += cVar_init_f(&cVar_Tnmu1lv4, 0.0f);
  numBytes += cSlice_init(&cSlice_7GpSjT8Q, 1, -1);
  numBytes += cVar_init_f(&cVar_H6SHbP19, 1337.0f);
  numBytes += cVar_init_f(&cVar_NPvjFeOh, 0.0f);
  numBytes += cIf_init(&cIf_lREsODL2, false);
  numBytes += cIf_init(&cIf_NOEjEeqx, false);
  numBytes += cBinop_init(&cBinop_hebEyLoZ, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ws4wWnVY, false);
  numBytes += cBinop_init(&cBinop_5zilqTyv, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_8dUk5Jsp, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_CZOBptAh, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Fubiy2pq, 0.0f);
  numBytes += cIf_init(&cIf_QTsvA0Mx, false);
  numBytes += cIf_init(&cIf_KZ7rifeI, false);
  numBytes += cBinop_init(&cBinop_PMaK0T6m, 0.0f); // __pow
  numBytes += cIf_init(&cIf_w9NBxhbz, false);
  numBytes += cBinop_init(&cBinop_4JXLlsLe, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_oZEDaV58, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Lx9ePBEg, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_5kjLC2zW, 0.0f);
  numBytes += cIf_init(&cIf_f64dc6Ze, false);
  numBytes += cIf_init(&cIf_ltGoyQ6p, false);
  numBytes += cBinop_init(&cBinop_mB9TgyXa, 0.0f); // __pow
  numBytes += cIf_init(&cIf_RYswPgDf, false);
  numBytes += cBinop_init(&cBinop_5ttfvSsM, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_7GxWs1bK, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_jnNnTR5G, -15.0f); // __eq
  numBytes += cIf_init(&cIf_ykOqk3vG, false);
  numBytes += cSlice_init(&cSlice_hsbSUrwK, 1, -1);
  numBytes += cVar_init_f(&cVar_6xp7lZBY, 0.0f);
  numBytes += cSlice_init(&cSlice_uj10FR44, 1, -1);
  numBytes += cVar_init_f(&cVar_R7e50zt1, 0.0f);
  numBytes += cSlice_init(&cSlice_p8aROdCI, 1, -1);
  numBytes += cVar_init_f(&cVar_XOAuYbrf, 0.0f);
  numBytes += cSlice_init(&cSlice_h9lE4Eco, 1, -1);
  numBytes += cVar_init_f(&cVar_Vs6tcyoq, 0.313f);
  numBytes += cBinop_init(&cBinop_eqqIpH1g, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_e9CVycuu, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_n3uU8nf0, 0.0f);
  numBytes += cVar_init_f(&cVar_KoNLIQx5, 1337.0f);
  numBytes += cVar_init_f(&cVar_sdv4W6oW, 0.3f);
  numBytes += cBinop_init(&cBinop_pTQ0Qnuj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lNkn3Ga1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DVtTEkIF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dH6Q1HMc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qCysgz3g, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9zMSysjr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bazRa21Y, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_kvjF0Lio, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_mSlBhfh9, 0.0f);
  numBytes += cVar_init_f(&cVar_RjecEVWI, 1337.0f);
  numBytes += cVar_init_f(&cVar_Abd7Syg8, 0.313f);
  numBytes += cBinop_init(&cBinop_9pRs5fRM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5ucv3A4F, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WDLmnjnF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FiX5h6RI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MUGQLzwg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_L2PUsRn2, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_t7dJTIgE, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_gkZ1VSnN, 0.0f);
  numBytes += cVar_init_f(&cVar_SazCgKBi, 1037.0f);
  numBytes += cVar_init_f(&cVar_0Z4b2KRU, 0.4f);
  numBytes += cBinop_init(&cBinop_8sCg6Wc2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DThiTjcB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ppz3eGOF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HQxjBAwj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3dxeSbG9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OGEkHd6R, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_jdlwQafr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HGZX12Ff, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ffyJKatY, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_wzqUEWLI, 1, -1);
  numBytes += cVar_init_f(&cVar_bSVi69lK, 1337.0f);
  numBytes += cVar_init_f(&cVar_zKO0yXAj, 0.0f);
  numBytes += cIf_init(&cIf_jEHIso5k, false);
  numBytes += cIf_init(&cIf_Fm0O7eHD, false);
  numBytes += cBinop_init(&cBinop_LzGT4VPn, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Xd17t7Hy, false);
  numBytes += cBinop_init(&cBinop_zINyl99i, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_DuqAinHb, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_ZCoFoA37, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_IeRnhihU, 0.0f);
  numBytes += cIf_init(&cIf_q1RKN5lq, false);
  numBytes += cIf_init(&cIf_mkTTYJGS, false);
  numBytes += cBinop_init(&cBinop_DMCqLlJl, 0.0f); // __pow
  numBytes += cIf_init(&cIf_PhExn7rk, false);
  numBytes += cBinop_init(&cBinop_c5ty18EX, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_rbj3NDDA, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_etErzS8q, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_G1GFjXpu, 0.0f);
  numBytes += cIf_init(&cIf_oandNBvJ, false);
  numBytes += cIf_init(&cIf_SbVD9Wkg, false);
  numBytes += cBinop_init(&cBinop_vOJspheo, 0.0f); // __pow
  numBytes += cIf_init(&cIf_jztiJFT5, false);
  numBytes += cBinop_init(&cBinop_x9lxETPZ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_VNNV4Yfr, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_JCY7R0Y2, -15.0f); // __eq
  numBytes += cIf_init(&cIf_Z1tctfYq, false);
  numBytes += cSlice_init(&cSlice_qjUAjRml, 1, -1);
  numBytes += cVar_init_f(&cVar_hVuOfNkt, 0.0f);
  numBytes += cSlice_init(&cSlice_k6BjqjOF, 1, -1);
  numBytes += cVar_init_f(&cVar_AAquVi1M, 0.0f);
  numBytes += cSlice_init(&cSlice_Qgmx7djy, 1, -1);
  numBytes += cVar_init_f(&cVar_b7cMftGC, 0.0f);
  numBytes += cSlice_init(&cSlice_xAjTEgbf, 1, -1);
  numBytes += cVar_init_f(&cVar_mNkJr63Y, 0.313f);
  numBytes += cBinop_init(&cBinop_UlDfxO0L, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_P4C8fW58, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_PA4hkrhS, 0.0f);
  numBytes += cVar_init_f(&cVar_oOZcm13O, 1337.0f);
  numBytes += cVar_init_f(&cVar_yZewYV3o, 0.3f);
  numBytes += cBinop_init(&cBinop_2CNndEvB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SRPR7m2H, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UtLZFthB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vxc3xI2t, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_epCKmSLo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PC7INQrH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZSrSyQuT, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_VSuGDP1p, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ILpZBe6Z, 0.0f);
  numBytes += cVar_init_f(&cVar_SQTfJ9Ea, 1337.0f);
  numBytes += cVar_init_f(&cVar_m0aSb2dn, 0.313f);
  numBytes += cBinop_init(&cBinop_YgwroRf3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RP7QTFDe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ybEOgmi3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MFcgAHxD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6nXViwUt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_N2VQLEhR, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_saDxiSeX, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_oj9nBeEs, 0.0f);
  numBytes += cVar_init_f(&cVar_JWMziohR, 1037.0f);
  numBytes += cVar_init_f(&cVar_aavqggoP, 0.4f);
  numBytes += cBinop_init(&cBinop_zUoJHbvO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_N9XjzjjN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xK8KRGzy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rQDBh4gl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_euLLcFNq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sf3fAPZA, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_7AoPXQxb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_e4gxZoUq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AsogQT9e, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_w79RflOK, 5705.6f);
  numBytes += cVar_init_f(&cVar_1vkVoZxx, 313.3f);
  numBytes += cBinop_init(&cBinop_eAbfmoZ0, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_xU7QA4JM, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_oIAvlYH7, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_3Q::~Heavy_WSTD_3Q() {
  // nothing to free
}

HvTable *Heavy_WSTD_3Q::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_3Q::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qLIQmfxW_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KC1WVNl8_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pO8V1uiL_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rU5mdeiq_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JIyjjiLf_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8vEJqnWh_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bNU4TIIN_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HUPXDW5N_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R9cy2Ysv_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NpF0aAwr_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dWWWTZWQ_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jGqv3Vx6_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JDpWucTq_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_73j2HJmv_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rJ26sfS8_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jKu0yItj_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YvOqjTZ5_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ABXz7iUY_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3ZwtFe7C_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zmdp69Yx_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_H175TvG0_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8FmCD9sG_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hr6uxl1s_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OXREbOjk_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_549cncYn_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NSbC8Ptm_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nRra6L6L_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GJ4lyiUB_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Rgu1mTlv_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NW8peV0P_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LH8SfY4G_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wVqPRdUB_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XoW3Mj2f_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_3Q::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_3Q::cVar_HWc6IAVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u3oDTOhN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_ce5rxbxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mRQIanqW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_6gUx0XYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ytXU2vx5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_Tnmu1lv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YiQnWADd_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IIn18TTA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tonmPamw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5Pv3iQRL_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_XpwdKxvD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7GpSjT8Q, 0, m, &cSlice_7GpSjT8Q_sendMessage);
      break;
    }
    default: {
      cSwitchcase_yRzJStOw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_7GpSjT8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GVAHID5V_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GVAHID5V_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_H6SHbP19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GVAHID5V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_GVAHID5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bNU4TIIN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_NPvjFeOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_e1v6i4DW_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_lREsODL2, 0, m, &cIf_lREsODL2_sendMessage);
}

void Heavy_WSTD_3Q::cIf_lREsODL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Or5OpTyP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_NOEjEeqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_0D7cfGEB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_7H7cRPxv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_sdUxd6eY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hebEyLoZ, HV_BINOP_POW, 0, m, &cBinop_hebEyLoZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hebEyLoZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ws4wWnVY, 0, m, &cIf_ws4wWnVY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_oU2ICHov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_LBGzAWnV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_lS41I3r8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YKHKxlSe_sendMessage);
}

void Heavy_WSTD_3Q::cCast_nZsjguEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NOEjEeqx, 0, m, &cIf_NOEjEeqx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YKHKxlSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NOEjEeqx, 1, m, &cIf_NOEjEeqx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7H7cRPxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_oU2ICHov_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_0D7cfGEB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ws4wWnVY, 0, m, &cIf_ws4wWnVY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LBGzAWnV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hebEyLoZ, HV_BINOP_POW, 1, m, &cBinop_hebEyLoZ_sendMessage);
  cMsg_sdUxd6eY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_ws4wWnVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_jdlwQafr, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_e1v6i4DW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lREsODL2, 1, m, &cIf_lREsODL2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Or5OpTyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8dUk5Jsp, HV_BINOP_GREATER_THAN, 1, m, &cBinop_8dUk5Jsp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CZOBptAh, HV_BINOP_EQ, 1, m, &cBinop_CZOBptAh_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_QOG5Uzqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5zilqTyv, HV_BINOP_ADD, 0, m, &cBinop_5zilqTyv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5zilqTyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lS41I3r8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nZsjguEO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8dUk5Jsp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ws4wWnVY, 1, m, &cIf_ws4wWnVY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CZOBptAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jkYquXqR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_jkYquXqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jdlwQafr, m);
}

void Heavy_WSTD_3Q::cCast_mjeKcVz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QOG5Uzqy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_CywyZjSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5zilqTyv, HV_BINOP_ADD, 1, m, &cBinop_5zilqTyv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8dUk5Jsp, HV_BINOP_GREATER_THAN, 0, m, &cBinop_8dUk5Jsp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CZOBptAh, HV_BINOP_EQ, 0, m, &cBinop_CZOBptAh_sendMessage);
}

void Heavy_WSTD_3Q::cCast_cjR2xmis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NPvjFeOh, 0, m, &cVar_NPvjFeOh_sendMessage);
}

void Heavy_WSTD_3Q::cVar_Fubiy2pq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nlY7zE1j_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_QTsvA0Mx, 0, m, &cIf_QTsvA0Mx_sendMessage);
}

void Heavy_WSTD_3Q::cIf_QTsvA0Mx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_grDK0kDP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_KZ7rifeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_5hHjgP42_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_MTf1u3qI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_bRwDwCMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PMaK0T6m, HV_BINOP_POW, 0, m, &cBinop_PMaK0T6m_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PMaK0T6m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w9NBxhbz, 0, m, &cIf_w9NBxhbz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UvN54Zex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_zeDMGH5o_sendMessage);
}

void Heavy_WSTD_3Q::cCast_WbapgckI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KZ7rifeI, 0, m, &cIf_KZ7rifeI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_V9uWouzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ppK8sCh3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ppK8sCh3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KZ7rifeI, 1, m, &cIf_KZ7rifeI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MTf1u3qI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_UvN54Zex_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_5hHjgP42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_w9NBxhbz, 0, m, &cIf_w9NBxhbz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zeDMGH5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PMaK0T6m, HV_BINOP_POW, 1, m, &cBinop_PMaK0T6m_sendMessage);
  cMsg_bRwDwCMP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_w9NBxhbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Ua0qyKZI_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_40uASuSw_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_YnI89Coo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_nlY7zE1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QTsvA0Mx, 1, m, &cIf_QTsvA0Mx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_grDK0kDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oZEDaV58, HV_BINOP_GREATER_THAN, 1, m, &cBinop_oZEDaV58_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lx9ePBEg, HV_BINOP_EQ, 1, m, &cBinop_Lx9ePBEg_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_2Fn7OGn9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4JXLlsLe, HV_BINOP_ADD, 0, m, &cBinop_4JXLlsLe_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4JXLlsLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V9uWouzC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WbapgckI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_oZEDaV58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w9NBxhbz, 1, m, &cIf_w9NBxhbz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Lx9ePBEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_akXpXCpU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_akXpXCpU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Ua0qyKZI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_40uASuSw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_YnI89Coo_sendMessage);
}

void Heavy_WSTD_3Q::cCast_fkaFYrp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Fubiy2pq, 0, m, &cVar_Fubiy2pq_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZOIUfFZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2Fn7OGn9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_FTyQwbOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4JXLlsLe, HV_BINOP_ADD, 1, m, &cBinop_4JXLlsLe_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oZEDaV58, HV_BINOP_GREATER_THAN, 0, m, &cBinop_oZEDaV58_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lx9ePBEg, HV_BINOP_EQ, 0, m, &cBinop_Lx9ePBEg_sendMessage);
}

void Heavy_WSTD_3Q::cVar_5kjLC2zW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2hn0BXwI_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_f64dc6Ze, 0, m, &cIf_f64dc6Ze_sendMessage);
}

void Heavy_WSTD_3Q::cIf_f64dc6Ze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_mahOD37x_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_ltGoyQ6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_sBxihtUW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_GBRRRtck_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_NHVfXl6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mB9TgyXa, HV_BINOP_POW, 0, m, &cBinop_mB9TgyXa_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mB9TgyXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RYswPgDf, 0, m, &cIf_RYswPgDf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sFnCyhdl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_tkvwgqbu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bQCj9vgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_obdC2t6F_sendMessage);
}

void Heavy_WSTD_3Q::cCast_86Zv9OBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ltGoyQ6p, 0, m, &cIf_ltGoyQ6p_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_obdC2t6F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ltGoyQ6p, 1, m, &cIf_ltGoyQ6p_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GBRRRtck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_sFnCyhdl_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_sBxihtUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_RYswPgDf, 0, m, &cIf_RYswPgDf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tkvwgqbu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mB9TgyXa, HV_BINOP_POW, 1, m, &cBinop_mB9TgyXa_sendMessage);
  cMsg_NHVfXl6S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_RYswPgDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_ffyJKatY, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_2hn0BXwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f64dc6Ze, 1, m, &cIf_f64dc6Ze_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mahOD37x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7GxWs1bK, HV_BINOP_GREATER_THAN, 1, m, &cBinop_7GxWs1bK_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jnNnTR5G, HV_BINOP_EQ, 1, m, &cBinop_jnNnTR5G_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_jZggJWzt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5ttfvSsM, HV_BINOP_ADD, 0, m, &cBinop_5ttfvSsM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5ttfvSsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bQCj9vgC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_86Zv9OBp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7GxWs1bK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RYswPgDf, 1, m, &cIf_RYswPgDf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jnNnTR5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WZT39LHz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_WZT39LHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ffyJKatY, m);
}

void Heavy_WSTD_3Q::cCast_2RLVZuxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5ttfvSsM, HV_BINOP_ADD, 1, m, &cBinop_5ttfvSsM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7GxWs1bK, HV_BINOP_GREATER_THAN, 0, m, &cBinop_7GxWs1bK_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jnNnTR5G, HV_BINOP_EQ, 0, m, &cBinop_jnNnTR5G_sendMessage);
}

void Heavy_WSTD_3Q::cCast_t253hYLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5kjLC2zW, 0, m, &cVar_5kjLC2zW_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7JvlI3Ew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jZggJWzt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_ykOqk3vG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_HGZX12Ff, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_qeoZqnE7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hsbSUrwK, 0, m, &cSlice_hsbSUrwK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_72hjn8vI_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_hsbSUrwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PCOxjgaW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PCOxjgaW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_6xp7lZBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PCOxjgaW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_PCOxjgaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JIyjjiLf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_72hjn8vI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uj10FR44, 0, m, &cSlice_uj10FR44_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XpwdKxvD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_uj10FR44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mPVmYHM2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mPVmYHM2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_R7e50zt1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mPVmYHM2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_mPVmYHM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_R9cy2Ysv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_yRzJStOw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_p8aROdCI, 0, m, &cSlice_p8aROdCI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lqomuwQJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_p8aROdCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_39TDzEcA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_39TDzEcA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_XOAuYbrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_39TDzEcA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_39TDzEcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8vEJqnWh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_lqomuwQJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_h9lE4Eco, 0, m, &cSlice_h9lE4Eco_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_h9lE4Eco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_79C5OsxI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_79C5OsxI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_Vs6tcyoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_79C5OsxI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_79C5OsxI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HUPXDW5N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_wmE0tAyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Og3Y6V0r, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_gjvVG19i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9is7O4M7, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_75jGIM68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PHoJCcf1, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_wUOdkBnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v1JlpMMw, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_wslGGkuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_31rkQYn2, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_RQ1GGBah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_i4pxS23S_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_i4pxS23S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eqqIpH1g, HV_BINOP_DIVIDE, 1, m, &cBinop_eqqIpH1g_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MVF22Fet_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_rICeGu8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_IEajVnpk_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_AAFNl6fl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_rICeGu8M_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IEajVnpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eqqIpH1g, HV_BINOP_DIVIDE, 0, m, &cBinop_eqqIpH1g_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MVF22Fet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AAFNl6fl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_eqqIpH1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e9CVycuu, HV_BINOP_MULTIPLY, 1, m, &cBinop_e9CVycuu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_e9CVycuu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B4ZV4PFF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zrHJeHWF_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_CLznDu1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ez2WBGMW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_JhKUdxNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tlngK0PH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_yrOpTZbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_2Hhr3nVh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2Hhr3nVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e9CVycuu, HV_BINOP_MULTIPLY, 0, m, &cBinop_e9CVycuu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CsHgHzWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_0olvmh1p_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0olvmh1p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hFhKxWAH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_9t4JqvkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n3uU8nf0, 1, m, &cVar_n3uU8nf0_sendMessage);
}

void Heavy_WSTD_3Q::cVar_n3uU8nf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ShLPTjGw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_MikBJ7oD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lNkn3Ga1, HV_BINOP_MULTIPLY, 1, m, &cBinop_lNkn3Ga1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mqw05fub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MikBJ7oD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6Ms1XaY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_HpoNkfCJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HpoNkfCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DVtTEkIF, HV_BINOP_MULTIPLY, 1, m, &cBinop_DVtTEkIF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qZqDFUl4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dH6Q1HMc, HV_BINOP_MULTIPLY, 1, m, &cBinop_dH6Q1HMc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xtq81xE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qZqDFUl4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VLxRrWeJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qCysgz3g, HV_BINOP_MULTIPLY, 1, m, &cBinop_qCysgz3g_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_rOspRtJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MiRnC7Nx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MiRnC7Nx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9zMSysjr, HV_BINOP_MULTIPLY, 1, m, &cBinop_9zMSysjr_sendMessage);
}

void Heavy_WSTD_3Q::cVar_KoNLIQx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o8cF8ZmU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_yrOpTZbh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GYuUx6K0_sendMessage);
}

void Heavy_WSTD_3Q::cVar_sdv4W6oW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_CsHgHzWQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_B4ZV4PFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_CLznDu1Z_sendMessage);
}

void Heavy_WSTD_3Q::cCast_zrHJeHWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_JhKUdxNa_sendMessage);
}

void Heavy_WSTD_3Q::cSend_ez2WBGMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jGqv3Vx6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_tlngK0PH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dWWWTZWQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_kp65Z9aJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NpF0aAwr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_hFhKxWAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_V8rydRkv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_V8rydRkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pTQ0Qnuj, HV_BINOP_MULTIPLY, 1, m, &cBinop_pTQ0Qnuj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pTQ0Qnuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_psXE1nIZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_psXE1nIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kp65Z9aJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_ShLPTjGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_baGmcKXy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_baGmcKXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ehuXJJMu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0z7HSICw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X6K5cwD2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lPmo5MIO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_33IeH11L_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OoFiVsII_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lNkn3Ga1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wmE0tAyq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_DVtTEkIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gjvVG19i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_dH6Q1HMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_75jGIM68_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_qCysgz3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wUOdkBnY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_9zMSysjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wslGGkuc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_goL8RmPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sdv4W6oW, 1, m, &cVar_sdv4W6oW_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4ppdJWjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KoNLIQx5, 0, m, &cVar_KoNLIQx5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_33IeH11L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DVtTEkIF, HV_BINOP_MULTIPLY, 0, m, &cBinop_DVtTEkIF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0z7HSICw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9zMSysjr, HV_BINOP_MULTIPLY, 0, m, &cBinop_9zMSysjr_sendMessage);
}

void Heavy_WSTD_3Q::cCast_lPmo5MIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dH6Q1HMc, HV_BINOP_MULTIPLY, 0, m, &cBinop_dH6Q1HMc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ehuXJJMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_OoFiVsII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lNkn3Ga1, HV_BINOP_MULTIPLY, 0, m, &cBinop_lNkn3Ga1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_X6K5cwD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qCysgz3g, HV_BINOP_MULTIPLY, 0, m, &cBinop_qCysgz3g_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GYuUx6K0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n3uU8nf0, 0, m, &cVar_n3uU8nf0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_o8cF8ZmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sdv4W6oW, 0, m, &cVar_sdv4W6oW_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_pynSfx5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1iPwB2LR, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_J39f5cG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XXoCS8vZ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ELAmGd86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2KltjeBi, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_NjtGDiyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lvl62LjQ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Hk59qfGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Tz30KZxw_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_Tz30KZxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bazRa21Y, HV_BINOP_DIVIDE, 1, m, &cBinop_bazRa21Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Iscot13q_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_1plNytzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_p34ApFs5_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_r5sNHAT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_1plNytzE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_p34ApFs5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bazRa21Y, HV_BINOP_DIVIDE, 0, m, &cBinop_bazRa21Y_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Iscot13q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r5sNHAT3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_bazRa21Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kvjF0Lio, HV_BINOP_MULTIPLY, 1, m, &cBinop_kvjF0Lio_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kvjF0Lio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RNvjQOu8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v7aGQMQk_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_DkxbKqiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wNBVHRqO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_0qx9fsCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QzNZwLbh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_i8kJKOuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_ieKzztyK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ieKzztyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kvjF0Lio, HV_BINOP_MULTIPLY, 0, m, &cBinop_kvjF0Lio_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZUUO2dKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_O0awxrfB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_O0awxrfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zLitiQ2g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_xymPz2G6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WDLmnjnF, HV_BINOP_MULTIPLY, 1, m, &cBinop_WDLmnjnF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_F7uy1CWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mSlBhfh9, 1, m, &cVar_mSlBhfh9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TfvkaB7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FiX5h6RI, HV_BINOP_MULTIPLY, 1, m, &cBinop_FiX5h6RI_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_9NAuyPgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_JjGrW07W_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JjGrW07W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MUGQLzwg, HV_BINOP_MULTIPLY, 1, m, &cBinop_MUGQLzwg_sendMessage);
}

void Heavy_WSTD_3Q::cVar_mSlBhfh9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nR8rJypK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_RjecEVWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jRHropoD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_i8kJKOuO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HFTw4eVw_sendMessage);
}

void Heavy_WSTD_3Q::cVar_Abd7Syg8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ZUUO2dKD_sendMessage);
}

void Heavy_WSTD_3Q::cCast_v7aGQMQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_0qx9fsCN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_RNvjQOu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_DkxbKqiY_sendMessage);
}

void Heavy_WSTD_3Q::cSend_wNBVHRqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rJ26sfS8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_QzNZwLbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_73j2HJmv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_YVPmeuJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JDpWucTq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_zLitiQ2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3797Uk5e_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3797Uk5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9pRs5fRM, HV_BINOP_MULTIPLY, 1, m, &cBinop_9pRs5fRM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9pRs5fRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jy68QWLQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jy68QWLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YVPmeuJq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_nR8rJypK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_JVHWS8zK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JVHWS8zK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AY670gQS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CHh77P1J_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0UwOKERn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uUJbkzYn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5ucv3A4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pynSfx5P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_WDLmnjnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J39f5cG4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_FiX5h6RI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ELAmGd86_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_MUGQLzwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NjtGDiyb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_1XTCvq0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Abd7Syg8, 1, m, &cVar_Abd7Syg8_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Lc9avZVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RjecEVWI, 0, m, &cVar_RjecEVWI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_jRHropoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Abd7Syg8, 0, m, &cVar_Abd7Syg8_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HFTw4eVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mSlBhfh9, 0, m, &cVar_mSlBhfh9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_CHh77P1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FiX5h6RI, HV_BINOP_MULTIPLY, 0, m, &cBinop_FiX5h6RI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_uUJbkzYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5ucv3A4F, HV_BINOP_MULTIPLY, 0, m, &cBinop_5ucv3A4F_sendMessage);
}

void Heavy_WSTD_3Q::cCast_AY670gQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MUGQLzwg, HV_BINOP_MULTIPLY, 0, m, &cBinop_MUGQLzwg_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0UwOKERn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WDLmnjnF, HV_BINOP_MULTIPLY, 0, m, &cBinop_WDLmnjnF_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_e57ktr5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HNVTpeGf, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_gErphokp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_trrNKxbS, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_WYWw58Cl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4NRO82kA, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_LTzycHrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jwNALUf6, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_VZ9pP0oi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n7GjnJiv, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_whsT4UHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hWL8L5jI_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_hWL8L5jI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L2PUsRn2, HV_BINOP_DIVIDE, 1, m, &cBinop_L2PUsRn2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6pEGmShW_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_xPUTXFnn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_X7kS4H3c_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_OrXuwMh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_xPUTXFnn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_X7kS4H3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L2PUsRn2, HV_BINOP_DIVIDE, 0, m, &cBinop_L2PUsRn2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6pEGmShW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OrXuwMh8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_L2PUsRn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t7dJTIgE, HV_BINOP_MULTIPLY, 1, m, &cBinop_t7dJTIgE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_t7dJTIgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P5HW5lkY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_o8YJpPLT_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_2LORDAR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZnSoxx0U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_voM4PwaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CeNVQz7V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ndr2U3Or_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_g0pRj59r_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_g0pRj59r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t7dJTIgE, HV_BINOP_MULTIPLY, 0, m, &cBinop_t7dJTIgE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6e7Uhztx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_MC3ruZ0a_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MC3ruZ0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_35FPnb94_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_tqmrxTbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DThiTjcB, HV_BINOP_MULTIPLY, 1, m, &cBinop_DThiTjcB_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_U4iwoFqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_U2izkEKN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_U2izkEKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tqmrxTbP_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_0w2py1fN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_r8yZjyft_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_r8yZjyft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ppz3eGOF, HV_BINOP_MULTIPLY, 1, m, &cBinop_ppz3eGOF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PeeSOgnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HQxjBAwj, HV_BINOP_MULTIPLY, 1, m, &cBinop_HQxjBAwj_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Ky9rbsWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5N2Yut5A_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5N2Yut5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PeeSOgnA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kOvoJ7IO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gkZ1VSnN, 1, m, &cVar_gkZ1VSnN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4sryQkdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3dxeSbG9, HV_BINOP_MULTIPLY, 1, m, &cBinop_3dxeSbG9_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_hiedeIiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_OacFCc86_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OacFCc86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OGEkHd6R, HV_BINOP_MULTIPLY, 1, m, &cBinop_OGEkHd6R_sendMessage);
}

void Heavy_WSTD_3Q::cVar_gkZ1VSnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BVvrbyqE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_SazCgKBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oR6oqa7j_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ndr2U3Or_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1H9NTrv7_sendMessage);
}

void Heavy_WSTD_3Q::cVar_0Z4b2KRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_6e7Uhztx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_o8YJpPLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_voM4PwaC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_P5HW5lkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_2LORDAR5_sendMessage);
}

void Heavy_WSTD_3Q::cSend_ZnSoxx0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ABXz7iUY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_CeNVQz7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YvOqjTZ5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_z8tDeLpp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jKu0yItj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_35FPnb94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_IeZxm0sk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IeZxm0sk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8sCg6Wc2, HV_BINOP_MULTIPLY, 1, m, &cBinop_8sCg6Wc2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8sCg6Wc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_XF2Yxubb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XF2Yxubb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_z8tDeLpp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_BVvrbyqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZocdQ1oE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZocdQ1oE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vnHim1xH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MgLaxgtk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wTvzGW49_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vfEnhVAT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JhoW8jiP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PYp49lsZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DThiTjcB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e57ktr5M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ppz3eGOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gErphokp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_HQxjBAwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WYWw58Cl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_3dxeSbG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LTzycHrS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_OGEkHd6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VZ9pP0oi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_mi3XEp6F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SazCgKBi, 0, m, &cVar_SazCgKBi_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Gj6mDK0W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0Z4b2KRU, 1, m, &cVar_0Z4b2KRU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_JhoW8jiP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ppz3eGOF, HV_BINOP_MULTIPLY, 0, m, &cBinop_ppz3eGOF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MgLaxgtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OGEkHd6R, HV_BINOP_MULTIPLY, 0, m, &cBinop_OGEkHd6R_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vfEnhVAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HQxjBAwj, HV_BINOP_MULTIPLY, 0, m, &cBinop_HQxjBAwj_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vnHim1xH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_PYp49lsZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DThiTjcB, HV_BINOP_MULTIPLY, 0, m, &cBinop_DThiTjcB_sendMessage);
}

void Heavy_WSTD_3Q::cCast_wTvzGW49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3dxeSbG9, HV_BINOP_MULTIPLY, 0, m, &cBinop_3dxeSbG9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1H9NTrv7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gkZ1VSnN, 0, m, &cVar_gkZ1VSnN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_oR6oqa7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0Z4b2KRU, 0, m, &cVar_0Z4b2KRU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ua0qyKZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ykOqk3vG, 1, m, &cIf_ykOqk3vG_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_RbKn87Hk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_HGZX12Ff, m);
}

void Heavy_WSTD_3Q::cBinop_40uASuSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RbKn87Hk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_YnI89Coo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ykOqk3vG, 0, m, &cIf_ykOqk3vG_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_EYFOKcCv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wzqUEWLI, 0, m, &cSlice_wzqUEWLI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_orlEtH7m_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_wzqUEWLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7vfvMTHD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7vfvMTHD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_bSVi69lK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7vfvMTHD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_7vfvMTHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_H175TvG0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_zKO0yXAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_e082C7Xp_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_jEHIso5k, 0, m, &cIf_jEHIso5k_sendMessage);
}

void Heavy_WSTD_3Q::cIf_jEHIso5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Amu8Hie0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_Fm0O7eHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_KL0hPJly_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_0siDkK0c_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_A5WhICxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LzGT4VPn, HV_BINOP_POW, 0, m, &cBinop_LzGT4VPn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LzGT4VPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Xd17t7Hy, 0, m, &cIf_Xd17t7Hy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4BbxV0aM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_6XC6vGpq_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ho7VqfSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VOq3iSEy_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3EsQ6Gtx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fm0O7eHD, 0, m, &cIf_Fm0O7eHD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VOq3iSEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fm0O7eHD, 1, m, &cIf_Fm0O7eHD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0siDkK0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_4BbxV0aM_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_KL0hPJly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Xd17t7Hy, 0, m, &cIf_Xd17t7Hy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6XC6vGpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LzGT4VPn, HV_BINOP_POW, 1, m, &cBinop_LzGT4VPn_sendMessage);
  cMsg_A5WhICxn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_Xd17t7Hy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_7AoPXQxb, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_e082C7Xp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jEHIso5k, 1, m, &cIf_jEHIso5k_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Amu8Hie0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DuqAinHb, HV_BINOP_GREATER_THAN, 1, m, &cBinop_DuqAinHb_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZCoFoA37, HV_BINOP_EQ, 1, m, &cBinop_ZCoFoA37_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_EHTlRCjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zINyl99i, HV_BINOP_ADD, 0, m, &cBinop_zINyl99i_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zINyl99i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ho7VqfSe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3EsQ6Gtx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DuqAinHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Xd17t7Hy, 1, m, &cIf_Xd17t7Hy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZCoFoA37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a21TpIvj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_a21TpIvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_7AoPXQxb, m);
}

void Heavy_WSTD_3Q::cCast_QoVU9FPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zKO0yXAj, 0, m, &cVar_zKO0yXAj_sendMessage);
}

void Heavy_WSTD_3Q::cCast_k2ZgYhmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EHTlRCjq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_XDP4YHYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zINyl99i, HV_BINOP_ADD, 1, m, &cBinop_zINyl99i_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DuqAinHb, HV_BINOP_GREATER_THAN, 0, m, &cBinop_DuqAinHb_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZCoFoA37, HV_BINOP_EQ, 0, m, &cBinop_ZCoFoA37_sendMessage);
}

void Heavy_WSTD_3Q::cVar_IeRnhihU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_57T8CW4h_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_q1RKN5lq, 0, m, &cIf_q1RKN5lq_sendMessage);
}

void Heavy_WSTD_3Q::cIf_q1RKN5lq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_cxc0SEYT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_mkTTYJGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_NwVqlYzo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_J8HsdcKl_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_Ifh0qtTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DMCqLlJl, HV_BINOP_POW, 0, m, &cBinop_DMCqLlJl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DMCqLlJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PhExn7rk, 0, m, &cIf_PhExn7rk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Un9CVF5Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_JHGe1hPB_sendMessage);
}

void Heavy_WSTD_3Q::cCast_iZVX67Zz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mkTTYJGS, 0, m, &cIf_mkTTYJGS_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZiCIqc5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Ui93XzCr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ui93XzCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mkTTYJGS, 1, m, &cIf_mkTTYJGS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_J8HsdcKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Un9CVF5Q_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_NwVqlYzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_PhExn7rk, 0, m, &cIf_PhExn7rk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JHGe1hPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DMCqLlJl, HV_BINOP_POW, 1, m, &cBinop_DMCqLlJl_sendMessage);
  cMsg_Ifh0qtTi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_PhExn7rk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vJkA8iS0_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iolx80je_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_b4qNLpvW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_57T8CW4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q1RKN5lq, 1, m, &cIf_q1RKN5lq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cxc0SEYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rbj3NDDA, HV_BINOP_GREATER_THAN, 1, m, &cBinop_rbj3NDDA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_etErzS8q, HV_BINOP_EQ, 1, m, &cBinop_etErzS8q_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ulwavWoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_c5ty18EX, HV_BINOP_ADD, 0, m, &cBinop_c5ty18EX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_c5ty18EX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZiCIqc5O_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iZVX67Zz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rbj3NDDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PhExn7rk, 1, m, &cIf_PhExn7rk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_etErzS8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dDz2wwqN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_dDz2wwqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vJkA8iS0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iolx80je_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_b4qNLpvW_sendMessage);
}

void Heavy_WSTD_3Q::cCast_L7g204Nk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c5ty18EX, HV_BINOP_ADD, 1, m, &cBinop_c5ty18EX_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rbj3NDDA, HV_BINOP_GREATER_THAN, 0, m, &cBinop_rbj3NDDA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_etErzS8q, HV_BINOP_EQ, 0, m, &cBinop_etErzS8q_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7yKmi1Oo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IeRnhihU, 0, m, &cVar_IeRnhihU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MBlKgfbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ulwavWoB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_G1GFjXpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_BbA6QSwf_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_oandNBvJ, 0, m, &cIf_oandNBvJ_sendMessage);
}

void Heavy_WSTD_3Q::cIf_oandNBvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_N1svQhTU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_SbVD9Wkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_HxQD8eYB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_os0gKze8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_V22FczGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vOJspheo, HV_BINOP_POW, 0, m, &cBinop_vOJspheo_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vOJspheo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jztiJFT5, 0, m, &cIf_jztiJFT5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_guNuAHOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_e4h3VEOG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_lfYsGEfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SbVD9Wkg, 0, m, &cIf_SbVD9Wkg_sendMessage);
}

void Heavy_WSTD_3Q::cCast_fEI8sh8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_asrgPICB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_asrgPICB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SbVD9Wkg, 1, m, &cIf_SbVD9Wkg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_os0gKze8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_guNuAHOB_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_HxQD8eYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_jztiJFT5, 0, m, &cIf_jztiJFT5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_e4h3VEOG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vOJspheo, HV_BINOP_POW, 1, m, &cBinop_vOJspheo_sendMessage);
  cMsg_V22FczGd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_jztiJFT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_AsogQT9e, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_BbA6QSwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oandNBvJ, 1, m, &cIf_oandNBvJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_N1svQhTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VNNV4Yfr, HV_BINOP_GREATER_THAN, 1, m, &cBinop_VNNV4Yfr_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JCY7R0Y2, HV_BINOP_EQ, 1, m, &cBinop_JCY7R0Y2_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ZW0v84Xw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_x9lxETPZ, HV_BINOP_ADD, 0, m, &cBinop_x9lxETPZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_x9lxETPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fEI8sh8u_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lfYsGEfG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VNNV4Yfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jztiJFT5, 1, m, &cIf_jztiJFT5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JCY7R0Y2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gyNJMxj5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_gyNJMxj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_AsogQT9e, m);
}

void Heavy_WSTD_3Q::cCast_dXn6eJbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x9lxETPZ, HV_BINOP_ADD, 1, m, &cBinop_x9lxETPZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VNNV4Yfr, HV_BINOP_GREATER_THAN, 0, m, &cBinop_VNNV4Yfr_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JCY7R0Y2, HV_BINOP_EQ, 0, m, &cBinop_JCY7R0Y2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_T61QZb1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_G1GFjXpu, 0, m, &cVar_G1GFjXpu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6CSP1KQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZW0v84Xw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_Z1tctfYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_e4gxZoUq, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_WVYmsszj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qjUAjRml, 0, m, &cSlice_qjUAjRml_sendMessage);
      break;
    }
    default: {
      cSwitchcase_psJcEKXa_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_qjUAjRml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QrW0hsfI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QrW0hsfI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_hVuOfNkt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QrW0hsfI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_QrW0hsfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3ZwtFe7C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_psJcEKXa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_k6BjqjOF, 0, m, &cSlice_k6BjqjOF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EYFOKcCv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_k6BjqjOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zh0om49V_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zh0om49V_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_AAquVi1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zh0om49V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_zh0om49V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hr6uxl1s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_orlEtH7m_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Qgmx7djy, 0, m, &cSlice_Qgmx7djy_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xLnwjVvT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_Qgmx7djy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Cg4RHL7g_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Cg4RHL7g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_b7cMftGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Cg4RHL7g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Cg4RHL7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zmdp69Yx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_xLnwjVvT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xAjTEgbf, 0, m, &cSlice_xAjTEgbf_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_xAjTEgbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dFRCr0cK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dFRCr0cK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_mNkJr63Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dFRCr0cK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_dFRCr0cK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8FmCD9sG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_UC7jAYSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GGMMDpU0, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_KeWNhldV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3vuatanm, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_fRqjxeP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9YuILwxD, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_m6Ao7qSS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_666XG9v1, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_9gizje5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BtP8oFJP, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_b1P1REeA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_n8y4p1Xh_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_n8y4p1Xh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UlDfxO0L, HV_BINOP_DIVIDE, 1, m, &cBinop_UlDfxO0L_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6wkdxJmi_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_VdH641wS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_s8NK7XYQ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_PYhkF7J8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_VdH641wS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_s8NK7XYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UlDfxO0L, HV_BINOP_DIVIDE, 0, m, &cBinop_UlDfxO0L_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6wkdxJmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PYhkF7J8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_UlDfxO0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P4C8fW58, HV_BINOP_MULTIPLY, 1, m, &cBinop_P4C8fW58_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_P4C8fW58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gh6YDOAe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lQcIFkBw_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_XOoQcJdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6W146eRr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_g42hRPmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yyUqCSc1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_2E0MXywV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_DDDeUtpA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DDDeUtpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P4C8fW58, HV_BINOP_MULTIPLY, 0, m, &cBinop_P4C8fW58_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_f5KTaHtA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_UIB00eJg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UIB00eJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lWubYwpO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Aa7hbjIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PA4hkrhS, 1, m, &cVar_PA4hkrhS_sendMessage);
}

void Heavy_WSTD_3Q::cVar_PA4hkrhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_THLGhb1y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_iJwnpbk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SRPR7m2H, HV_BINOP_MULTIPLY, 1, m, &cBinop_SRPR7m2H_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cKfur8Rr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_iJwnpbk0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8kcwDvEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_V7MTcYuj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_V7MTcYuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UtLZFthB, HV_BINOP_MULTIPLY, 1, m, &cBinop_UtLZFthB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Hh8Ur0Un_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vxc3xI2t, HV_BINOP_MULTIPLY, 1, m, &cBinop_vxc3xI2t_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aREbkuFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Hh8Ur0Un_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LQVMuCHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_epCKmSLo, HV_BINOP_MULTIPLY, 1, m, &cBinop_epCKmSLo_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_KGqyefLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FdrdMIL8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FdrdMIL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PC7INQrH, HV_BINOP_MULTIPLY, 1, m, &cBinop_PC7INQrH_sendMessage);
}

void Heavy_WSTD_3Q::cVar_oOZcm13O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CVOky5bp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_2E0MXywV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D9gd0JfN_sendMessage);
}

void Heavy_WSTD_3Q::cVar_yZewYV3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_f5KTaHtA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_gh6YDOAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_XOoQcJdE_sendMessage);
}

void Heavy_WSTD_3Q::cCast_lQcIFkBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_g42hRPmL_sendMessage);
}

void Heavy_WSTD_3Q::cSend_6W146eRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NSbC8Ptm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_yyUqCSc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_549cncYn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_TGCw4Spv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OXREbOjk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_lWubYwpO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_FXdmFM0s_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FXdmFM0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2CNndEvB, HV_BINOP_MULTIPLY, 1, m, &cBinop_2CNndEvB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2CNndEvB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_IGjaglAd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IGjaglAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TGCw4Spv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_THLGhb1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_UtWHJjmu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UtWHJjmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HitjKJcZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X48kFMVp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OjUl7MIY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8m73RV55_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qOacrByQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6antjCjo_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SRPR7m2H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UC7jAYSD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_UtLZFthB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KeWNhldV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_vxc3xI2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fRqjxeP2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_epCKmSLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m6Ao7qSS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_PC7INQrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9gizje5a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_s1VFcFPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oOZcm13O, 0, m, &cVar_oOZcm13O_sendMessage);
}

void Heavy_WSTD_3Q::cCast_AplqDEY1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yZewYV3o, 1, m, &cVar_yZewYV3o_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8m73RV55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vxc3xI2t, HV_BINOP_MULTIPLY, 0, m, &cBinop_vxc3xI2t_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HitjKJcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_6antjCjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SRPR7m2H, HV_BINOP_MULTIPLY, 0, m, &cBinop_SRPR7m2H_sendMessage);
}

void Heavy_WSTD_3Q::cCast_OjUl7MIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_epCKmSLo, HV_BINOP_MULTIPLY, 0, m, &cBinop_epCKmSLo_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qOacrByQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UtLZFthB, HV_BINOP_MULTIPLY, 0, m, &cBinop_UtLZFthB_sendMessage);
}

void Heavy_WSTD_3Q::cCast_X48kFMVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PC7INQrH, HV_BINOP_MULTIPLY, 0, m, &cBinop_PC7INQrH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_CVOky5bp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yZewYV3o, 0, m, &cVar_yZewYV3o_sendMessage);
}

void Heavy_WSTD_3Q::cCast_D9gd0JfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PA4hkrhS, 0, m, &cVar_PA4hkrhS_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_P3GASDFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h4Ppof0C, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_l5cZG1Yg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_98sQzXsc, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Mz37AkSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oekDbTAm, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_J4nXO2Ni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oDeY93W9, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_nuTbPttV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yPW16tj7_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_yPW16tj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZSrSyQuT, HV_BINOP_DIVIDE, 1, m, &cBinop_ZSrSyQuT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4fNfDQLa_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_KF1J2z76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_QJ8vVdai_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_a8ypJpcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_KF1J2z76_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QJ8vVdai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZSrSyQuT, HV_BINOP_DIVIDE, 0, m, &cBinop_ZSrSyQuT_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4fNfDQLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a8ypJpcH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ZSrSyQuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VSuGDP1p, HV_BINOP_MULTIPLY, 1, m, &cBinop_VSuGDP1p_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VSuGDP1p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YYQ9loYG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RbPnW3Km_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_3wmIAXBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lArX4fcI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_bKz91KEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_q0JWF427_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_gMjWVFIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_zYX15Pjx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zYX15Pjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VSuGDP1p, HV_BINOP_MULTIPLY, 0, m, &cBinop_VSuGDP1p_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_acBZl4Pv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_ftxYqkKq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ftxYqkKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uggBWCpt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_16nfApts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ybEOgmi3, HV_BINOP_MULTIPLY, 1, m, &cBinop_ybEOgmi3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Avd4E3nM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ILpZBe6Z, 1, m, &cVar_ILpZBe6Z_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AfTpKEnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MFcgAHxD, HV_BINOP_MULTIPLY, 1, m, &cBinop_MFcgAHxD_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Z94GvJiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vDL4WMUD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vDL4WMUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6nXViwUt, HV_BINOP_MULTIPLY, 1, m, &cBinop_6nXViwUt_sendMessage);
}

void Heavy_WSTD_3Q::cVar_ILpZBe6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_myMUcEvP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_SQTfJ9Ea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jPbEAbXq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_gMjWVFIg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bMqpKjca_sendMessage);
}

void Heavy_WSTD_3Q::cVar_m0aSb2dn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_acBZl4Pv_sendMessage);
}

void Heavy_WSTD_3Q::cCast_YYQ9loYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_3wmIAXBi_sendMessage);
}

void Heavy_WSTD_3Q::cCast_RbPnW3Km_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_bKz91KEi_sendMessage);
}

void Heavy_WSTD_3Q::cSend_lArX4fcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Rgu1mTlv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_q0JWF427_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GJ4lyiUB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Mjsd84wx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nRra6L6L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_uggBWCpt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_sachAfId_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sachAfId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YgwroRf3, HV_BINOP_MULTIPLY, 1, m, &cBinop_YgwroRf3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YgwroRf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3Uu7IY0a_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3Uu7IY0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Mjsd84wx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_myMUcEvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6pogM5Av_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6pogM5Av_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zwMdrh8l_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1bRP4tyC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vJyJPrj8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zhy6H6Ov_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RP7QTFDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P3GASDFN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ybEOgmi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l5cZG1Yg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_MFcgAHxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mz37AkSD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_6nXViwUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J4nXO2Ni_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_OMgNXSWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m0aSb2dn, 1, m, &cVar_m0aSb2dn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_opYS0mMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SQTfJ9Ea, 0, m, &cVar_SQTfJ9Ea_sendMessage);
}

void Heavy_WSTD_3Q::cCast_jPbEAbXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m0aSb2dn, 0, m, &cVar_m0aSb2dn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bMqpKjca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ILpZBe6Z, 0, m, &cVar_ILpZBe6Z_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1bRP4tyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MFcgAHxD, HV_BINOP_MULTIPLY, 0, m, &cBinop_MFcgAHxD_sendMessage);
}

void Heavy_WSTD_3Q::cCast_zhy6H6Ov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RP7QTFDe, HV_BINOP_MULTIPLY, 0, m, &cBinop_RP7QTFDe_sendMessage);
}

void Heavy_WSTD_3Q::cCast_zwMdrh8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6nXViwUt, HV_BINOP_MULTIPLY, 0, m, &cBinop_6nXViwUt_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vJyJPrj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ybEOgmi3, HV_BINOP_MULTIPLY, 0, m, &cBinop_ybEOgmi3_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_lEiBu7Vk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iTxriYEv, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_73rvPnQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fcBRm7bf, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_geH0Q91o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UUCSAb9B, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_MpXGpX6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CvLUvaMN, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_vGvp74Bz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XsXT1zyS, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_BsaGWeq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bXUOV6QY_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_bXUOV6QY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N2VQLEhR, HV_BINOP_DIVIDE, 1, m, &cBinop_N2VQLEhR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DWyBPkO4_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_MxdtgRRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_KODOsvvH_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_BJFYweXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_MxdtgRRw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KODOsvvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N2VQLEhR, HV_BINOP_DIVIDE, 0, m, &cBinop_N2VQLEhR_sendMessage);
}

void Heavy_WSTD_3Q::cCast_DWyBPkO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BJFYweXr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_N2VQLEhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_saDxiSeX, HV_BINOP_MULTIPLY, 1, m, &cBinop_saDxiSeX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_saDxiSeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3gl339YG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VRQARalf_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_VYiAOTqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_J1pFqNCy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_QEByBm40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tXomlpUu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_WOV9wfLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_tylbFYv7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tylbFYv7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_saDxiSeX, HV_BINOP_MULTIPLY, 0, m, &cBinop_saDxiSeX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_esqiNizP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_I2aqX8c7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_I2aqX8c7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dGBIHsdl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_i4oxQJwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N9XjzjjN, HV_BINOP_MULTIPLY, 1, m, &cBinop_N9XjzjjN_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_IYLSnDYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_cX958Wbt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cX958Wbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_i4oxQJwW_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Hnx4yXhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9pTh89uj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9pTh89uj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xK8KRGzy, HV_BINOP_MULTIPLY, 1, m, &cBinop_xK8KRGzy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CK7RET7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rQDBh4gl, HV_BINOP_MULTIPLY, 1, m, &cBinop_rQDBh4gl_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_81Iu2Sap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_P2JzNTBq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_P2JzNTBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CK7RET7P_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_C2dK1pKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oj9nBeEs, 1, m, &cVar_oj9nBeEs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XMxmGJuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_euLLcFNq, HV_BINOP_MULTIPLY, 1, m, &cBinop_euLLcFNq_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_XOkQGZbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_pGHVWAFp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pGHVWAFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sf3fAPZA, HV_BINOP_MULTIPLY, 1, m, &cBinop_sf3fAPZA_sendMessage);
}

void Heavy_WSTD_3Q::cVar_oj9nBeEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7U0PcHSI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_JWMziohR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZsS7w0wI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_WOV9wfLH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3hkb3HLc_sendMessage);
}

void Heavy_WSTD_3Q::cVar_aavqggoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_esqiNizP_sendMessage);
}

void Heavy_WSTD_3Q::cCast_VRQARalf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_QEByBm40_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3gl339YG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_VYiAOTqZ_sendMessage);
}

void Heavy_WSTD_3Q::cSend_J1pFqNCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wVqPRdUB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_tXomlpUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LH8SfY4G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_VHbO4qVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NW8peV0P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_dGBIHsdl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_mqonuTkv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mqonuTkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zUoJHbvO, HV_BINOP_MULTIPLY, 1, m, &cBinop_zUoJHbvO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zUoJHbvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SqWXhKt3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SqWXhKt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VHbO4qVg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_7U0PcHSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9xUsWIcX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9xUsWIcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sYefjUYZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oXvIyUh0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bv9wxDPq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z2UqJ9lu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nZeXMroB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zQE9ol4v_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_N9XjzjjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lEiBu7Vk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_xK8KRGzy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_73rvPnQI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_rQDBh4gl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_geH0Q91o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_euLLcFNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MpXGpX6K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_sf3fAPZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vGvp74Bz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_YVBZK79v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aavqggoP, 1, m, &cVar_aavqggoP_sendMessage);
}

void Heavy_WSTD_3Q::cCast_hoMjxJR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JWMziohR, 0, m, &cVar_JWMziohR_sendMessage);
}

void Heavy_WSTD_3Q::cCast_nZeXMroB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xK8KRGzy, HV_BINOP_MULTIPLY, 0, m, &cBinop_xK8KRGzy_sendMessage);
}

void Heavy_WSTD_3Q::cCast_oXvIyUh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sf3fAPZA, HV_BINOP_MULTIPLY, 0, m, &cBinop_sf3fAPZA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Z2UqJ9lu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rQDBh4gl, HV_BINOP_MULTIPLY, 0, m, &cBinop_rQDBh4gl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_sYefjUYZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_zQE9ol4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N9XjzjjN, HV_BINOP_MULTIPLY, 0, m, &cBinop_N9XjzjjN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Bv9wxDPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_euLLcFNq, HV_BINOP_MULTIPLY, 0, m, &cBinop_euLLcFNq_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZsS7w0wI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aavqggoP, 0, m, &cVar_aavqggoP_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3hkb3HLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oj9nBeEs, 0, m, &cVar_oj9nBeEs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vJkA8iS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z1tctfYq, 1, m, &cIf_Z1tctfYq_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_q85JO5Ul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_e4gxZoUq, m);
}

void Heavy_WSTD_3Q::cBinop_iolx80je_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q85JO5Ul_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_b4qNLpvW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z1tctfYq, 0, m, &cIf_Z1tctfYq_sendMessage);
}

void Heavy_WSTD_3Q::cVar_w79RflOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xU7QA4JM, HV_BINOP_DIVIDE, 0, m, &cBinop_xU7QA4JM_sendMessage);
}

void Heavy_WSTD_3Q::cVar_1vkVoZxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eAbfmoZ0, HV_BINOP_DIVIDE, 1, m, &cBinop_eAbfmoZ0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xU7QA4JM, HV_BINOP_DIVIDE, 1, m, &cBinop_xU7QA4JM_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_dylpQ7zW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oIAvlYH7, HV_BINOP_DIVIDE, 0, m, &cBinop_oIAvlYH7_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_CkgvEdwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oIAvlYH7, HV_BINOP_DIVIDE, 1, m, &cBinop_oIAvlYH7_sendMessage);
}

void Heavy_WSTD_3Q::cCast_tonmPamw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w79RflOK, 0, m, &cVar_w79RflOK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_IIn18TTA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1vkVoZxx, 0, m, &cVar_1vkVoZxx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5Pv3iQRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eAbfmoZ0, HV_BINOP_DIVIDE, 0, m, &cBinop_eAbfmoZ0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eAbfmoZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_dylpQ7zW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xU7QA4JM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_CkgvEdwP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_oIAvlYH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_rojG8Uj5_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_5NuWKBGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_bTLxkLEo_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QUt9KkEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_60nZqGzJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rojG8Uj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_QUt9KkEO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_60nZqGzJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_5NuWKBGd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bTLxkLEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AcQzEpcW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_u3oDTOhN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_qeoZqnE7_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WVYmsszj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_mRQIanqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_qeoZqnE7_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WVYmsszj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ytXU2vx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_qeoZqnE7_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WVYmsszj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_YiQnWADd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_qeoZqnE7_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WVYmsszj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_AcQzEpcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_qeoZqnE7_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WVYmsszj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_YfO8bbU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Tnmu1lv4, 0, m, &cVar_Tnmu1lv4_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_2faIB6y2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_HWc6IAVH, 0, m, &cVar_HWc6IAVH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ce5rxbxq, 0, m, &cVar_ce5rxbxq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6gUx0XYH, 0, m, &cVar_6gUx0XYH_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_qLIQmfxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HWc6IAVH, 0, m, &cVar_HWc6IAVH_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_pO8V1uiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ce5rxbxq, 0, m, &cVar_ce5rxbxq_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_KC1WVNl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6gUx0XYH, 0, m, &cVar_6gUx0XYH_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_bNU4TIIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RjecEVWI, 0, m, &cVar_RjecEVWI_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_HUPXDW5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1XTCvq0i_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Lc9avZVt_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_JIyjjiLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cjR2xmis_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CywyZjSe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mjeKcVz5_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_8vEJqnWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t253hYLE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2RLVZuxC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7JvlI3Ew_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_R9cy2Ysv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fkaFYrp5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FTyQwbOS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZOIUfFZu_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_XoW3Mj2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RQ1GGBah_sendMessage(_c, 0, m);
  cMsg_Hk59qfGE_sendMessage(_c, 0, m);
  cMsg_whsT4UHh_sendMessage(_c, 0, m);
  cMsg_b1P1REeA_sendMessage(_c, 0, m);
  cMsg_nuTbPttV_sendMessage(_c, 0, m);
  cMsg_BsaGWeq9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_KoNLIQx5, 0, m, &cVar_KoNLIQx5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RjecEVWI, 0, m, &cVar_RjecEVWI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SazCgKBi, 0, m, &cVar_SazCgKBi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oOZcm13O, 0, m, &cVar_oOZcm13O_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SQTfJ9Ea, 0, m, &cVar_SQTfJ9Ea_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JWMziohR, 0, m, &cVar_JWMziohR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_H6SHbP19, 0, m, &cVar_H6SHbP19_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NPvjFeOh, 0, m, &cVar_NPvjFeOh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Fubiy2pq, 0, m, &cVar_Fubiy2pq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5kjLC2zW, 0, m, &cVar_5kjLC2zW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6xp7lZBY, 0, m, &cVar_6xp7lZBY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_R7e50zt1, 0, m, &cVar_R7e50zt1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XOAuYbrf, 0, m, &cVar_XOAuYbrf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Vs6tcyoq, 0, m, &cVar_Vs6tcyoq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bSVi69lK, 0, m, &cVar_bSVi69lK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zKO0yXAj, 0, m, &cVar_zKO0yXAj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IeRnhihU, 0, m, &cVar_IeRnhihU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_G1GFjXpu, 0, m, &cVar_G1GFjXpu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hVuOfNkt, 0, m, &cVar_hVuOfNkt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AAquVi1M, 0, m, &cVar_AAquVi1M_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_b7cMftGC, 0, m, &cVar_b7cMftGC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mNkJr63Y, 0, m, &cVar_mNkJr63Y_sendMessage);
  cMsg_2faIB6y2_sendMessage(_c, 0, m);
  cMsg_YfO8bbU9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_jGqv3Vx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pTQ0Qnuj, HV_BINOP_MULTIPLY, 0, m, &cBinop_pTQ0Qnuj_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_dWWWTZWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mqw05fub_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_6Ms1XaY3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xtq81xE8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_VLxRrWeJ_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_NpF0aAwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9t4JqvkL_sendMessage);
  cMsg_rOspRtJ0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_rJ26sfS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9pRs5fRM, HV_BINOP_MULTIPLY, 0, m, &cBinop_9pRs5fRM_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_73j2HJmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_TfvkaB7R_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_JDpWucTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5ucv3A4F, HV_BINOP_MULTIPLY, 1, m, &cBinop_5ucv3A4F_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xymPz2G6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_F7uy1CWm_sendMessage);
  cMsg_9NAuyPgM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_ABXz7iUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8sCg6Wc2, HV_BINOP_MULTIPLY, 0, m, &cBinop_8sCg6Wc2_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_YvOqjTZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U4iwoFqN_sendMessage(_c, 0, m);
  cMsg_0w2py1fN_sendMessage(_c, 0, m);
  cMsg_Ky9rbsWN_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_4sryQkdM_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_jKu0yItj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_kOvoJ7IO_sendMessage);
  cMsg_hiedeIiu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_H175TvG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SQTfJ9Ea, 0, m, &cVar_SQTfJ9Ea_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_8FmCD9sG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OMgNXSWu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_opYS0mMY_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_3ZwtFe7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QoVU9FPP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XDP4YHYl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k2ZgYhmO_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_zmdp69Yx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T61QZb1U_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dXn6eJbE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6CSP1KQm_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_hr6uxl1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7yKmi1Oo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L7g204Nk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MBlKgfbn_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_NSbC8Ptm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2CNndEvB, HV_BINOP_MULTIPLY, 0, m, &cBinop_2CNndEvB_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_549cncYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_cKfur8Rr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8kcwDvEV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_aREbkuFG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_LQVMuCHc_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_OXREbOjk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Aa7hbjIS_sendMessage);
  cMsg_KGqyefLj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_Rgu1mTlv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YgwroRf3, HV_BINOP_MULTIPLY, 0, m, &cBinop_YgwroRf3_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_GJ4lyiUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_AfTpKEnB_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_nRra6L6L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RP7QTFDe, HV_BINOP_MULTIPLY, 1, m, &cBinop_RP7QTFDe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_16nfApts_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Avd4E3nM_sendMessage);
  cMsg_Z94GvJiG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_wVqPRdUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zUoJHbvO, HV_BINOP_MULTIPLY, 0, m, &cBinop_zUoJHbvO_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_LH8SfY4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IYLSnDYt_sendMessage(_c, 0, m);
  cMsg_Hnx4yXhg_sendMessage(_c, 0, m);
  cMsg_81Iu2Sap_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_XMxmGJuT_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_NW8peV0P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_C2dK1pKr_sendMessage);
  cMsg_XOkQGZbm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_rU5mdeiq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Tnmu1lv4, 0, m, &cVar_Tnmu1lv4_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_3Q::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9;

  // input and output vars
  hv_bufferf_t O0, O1, O2, O3, O4, O5;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));
    __hv_zero_f(VOf(O2));
    __hv_zero_f(VOf(O3));
    __hv_zero_f(VOf(O4));
    __hv_zero_f(VOf(O5));

    // process all signal functions
    __hv_line_f(&sLine_Og3Y6V0r, VOf(Bf0));
    __hv_line_f(&sLine_9is7O4M7, VOf(Bf1));
    __hv_line_f(&sLine_PHoJCcf1, VOf(Bf2));
    __hv_line_f(&sLine_v1JlpMMw, VOf(Bf3));
    __hv_line_f(&sLine_31rkQYn2, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_jmzbzK8D, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_jdlwQafr, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_1iPwB2LR, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_XXoCS8vZ, VOf(Bf1));
    __hv_line_f(&sLine_2KltjeBi, VOf(Bf0));
    __hv_line_f(&sLine_lvl62LjQ, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_TBqWJA8n, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_HGZX12Ff, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_HNVTpeGf, VOf(Bf5));
    __hv_line_f(&sLine_trrNKxbS, VOf(Bf1));
    __hv_line_f(&sLine_4NRO82kA, VOf(Bf2));
    __hv_line_f(&sLine_jwNALUf6, VOf(Bf4));
    __hv_line_f(&sLine_n7GjnJiv, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_HYwkXwZy, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_ffyJKatY, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_GGMMDpU0, VOf(Bf6));
    __hv_line_f(&sLine_3vuatanm, VOf(Bf2));
    __hv_line_f(&sLine_9YuILwxD, VOf(Bf1));
    __hv_line_f(&sLine_666XG9v1, VOf(Bf5));
    __hv_line_f(&sLine_BtP8oFJP, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_uelArOWn, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_7AoPXQxb, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_h4Ppof0C, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_98sQzXsc, VOf(Bf2));
    __hv_line_f(&sLine_oekDbTAm, VOf(Bf6));
    __hv_line_f(&sLine_oDeY93W9, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_r7XiqGdg, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_e4gxZoUq, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_iTxriYEv, VOf(Bf8));
    __hv_line_f(&sLine_fcBRm7bf, VOf(Bf2));
    __hv_line_f(&sLine_UUCSAb9B, VOf(Bf1));
    __hv_line_f(&sLine_CvLUvaMN, VOf(Bf7));
    __hv_line_f(&sLine_XsXT1zyS, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_M176WEDg, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_AsogQT9e, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf6), VIf(O3), VOf(O3));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf4), VIf(O4), VOf(O4));
    __hv_add_f(VIf(Bf0), VIf(O2), VOf(O2));
    __hv_add_f(VIf(Bf7), VIf(O5), VOf(O5));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
    __hv_store_f(outputBuffers[2]+n, VIf(O2));
    __hv_store_f(outputBuffers[3]+n, VIf(O3));
    __hv_store_f(outputBuffers[4]+n, VIf(O4));
    __hv_store_f(outputBuffers[5]+n, VIf(O5));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_3Q::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 6 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(6*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);
  bOut[2] = outputBuffers+(2*n4);
  bOut[3] = outputBuffers+(3*n4);
  bOut[4] = outputBuffers+(4*n4);
  bOut[5] = outputBuffers+(5*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_3Q::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 6 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(6*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  
  // interleave the heavy output into the output buffer
  for (int i = 0; i < 6; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+6*j] = bOut[i*n4+j];
    }
  }

  return n;
}
